@@ -43,7 +43,7 @@
 #'  
 #'  **subtribe** The subtribe of bee which the species belongs to.
 #'  
-#'  **validName** The valid scientific name as it should occur in the “scientificName” column in a Darwin Core file.
+#'  **validName** The valid scientific name as it should occur in the 'scientificName" column in a Darwin Core file.
 #'  
 #'  **canonical** The scientificName without the scientificNameAuthority.
 #'  
@@ -66,6 +66,13 @@
 #'
 #' @param URL A character vector to the FigShare location of the dataset. The default will be to
 #' the most-recent version.
+#' @param destfile a character string (or vector, see the url argument) with the file path where 
+#' the downloaded file is to be saved. Tilde-expansion is performed. If NULL (default), then destfile
+#' is set as `paste0(tempdir(), "/beesTaxonomy.Rda")` (normalizePath for Windows).
+#' @param method The method to be used for downloading files. Current download methods are 
+#' "internal", "libcurl", "wget", "curl" and "wininet" (Windows only), and there is a value 
+#' "auto": see ‘Details’ and ‘Note’. The method can also be set through the option 
+#' "download.file.method": see options(). description
 #' @param ... Extra variables that can be passed to [utils::download.file()]
 #'
 #'
@@ -76,13 +83,14 @@
 #' 
 #' @references This dataset was created using the Discover Life taxonomy.
 #' Dataset is from the publication: 
-#' DOREY, J. B., CHESSHIRE, P. R., BOLAÑOS, A. N., O’REILLY, R. L., BOSSERT, S., COLLINS, S. M., LICHTENBERG, E. M., TUCKER, E., SMITH-PARDO, A., FALCON-BRINDIS, A., GUEVARA, D. A., RIBEIRO, B. R., DE PEDRO, D., FISCHER, E., HUNG, J. K.-L., PARYS, K. A., ROGAN, M. S., MINCKLEY, R. L., VELZCO, S. J. E., GRISWOLD, T., ZARRILLO, T. A., SICA, Y., ORR, M. C., GUZMAN, L. M., ASCHER, J., HUGHES, A. C. & COBB, N. S. In review. A globally synthesised and flagged bee occurrence dataset and cleaning workflow. Scientific Data.
+#' Dorey, J.B., Fischer, E.E., Chesshire, P.R., Nava-Bolaños, A., O’Reilly, R.L., Bossert, S., Collins, S.M., Lichtenberg, E.M., Tucker, E., Smith-Pardo, A., Falcon-Brindis, A., Guevara, D.A., Ribeiro, B.R., de Pedro, D., Hung, J.K.-L., Parys, K.A., McCabe, L.M., Rogan, M.S., Minckley, R.L., Velzco, S.J.E., Griswold, T., Zarrillo, T.A., Jetz, W., Sica, Y.V., Orr, M.C., Guzman, L.M., Ascher, J., Hughes, A.C. & Cobb, N.S. (2023) A globally synthesised and flagged bee occurrence dataset and cleaning workflow. Scientific Data, 10, 1–17. https://www.doi.org/10.1038/S41597-023-02626-W
 #' The taxonomy data are mostly compiled from Discover Life data, www.discoverlife.org:
-#' ASCHER, J. S. & PICKERING, J. 2020. Discover Life bee species guide and world checklist (Hymenoptera: Apoidea: Anthophila). http://www.discoverlife.org/mp/20q?guide=Apoidea_species.
+#' Ascher, J.S. & Pickering, J. (2020) Discover Life bee species guide and world checklist (Hymenoptera: Apoidea: Anthophila). http://www.discoverlife.org/mp/20q?guide=Apoidea_species
 #'
 #' @seealso [BeeBDC::taxadbToBeeBDC()] to download any other taxonomy (of any taxa or of bees)
 #' and [BeeBDC::harmoniseR()] for the 
-#' taxon-cleaning function where these taxonomies are implemented.
+#' taxon-cleaning function where these taxonomies are implemented. It may also be worth seeing 
+#' [BeeBDC::beesChecklist()].
 #' 
 #' @export
 #' 
@@ -92,7 +100,8 @@
 #'}
 #' 
 #'
-beesTaxonomy <- function(URL = "https://open.flinders.edu.au/ndownloader/files/43331472",
+beesTaxonomy <- function(URL = "https://open.flinders.edu.au/ndownloader/files/47089969",
+                         destfile = NULL, method = "auto",
                          ...){
   destfile <- taxonomy <- attempt <- nAttempts <- error_funcFile <- error_func <-  NULL
 
@@ -101,10 +110,10 @@ beesTaxonomy <- function(URL = "https://open.flinders.edu.au/ndownloader/files/4
   
   # Set up the error message function
   error_func <- function(e){
-    message(paste("Download attempt failed..."))
+    message(paste("Taxonomy download attempt failed..."))
   }
   error_funcFile <- function(e){
-    message(paste("Could not read download..."))
+    message(paste("Could not read taxonomy download..."))
   }
   # Check operating system
   OS <- dplyr::if_else(.Platform$OS.type == "unix",
@@ -122,17 +131,28 @@ beesTaxonomy <- function(URL = "https://open.flinders.edu.au/ndownloader/files/4
       
 # WINDOWS
       if(OS != "MacLinux"){
+        # Set destfile if it's not provided by user
+        if(is.null(destfile)){
+          destfile <- normalizePath(paste0(tempdir(),
+                                           "/beesTaxonomy.Rda"))}
     # Download the file to the outPath 
-    tryCatch(utils::download.file(URL, destfile = normalizePath(paste0(tempdir(), 
-                                                                       "/beesTaxonomy.Rda"))),
+    tryCatch(utils::download.file(URL, destfile = destfile,
+                                  method = method,
+                                  ...),
         error = error_func, warning = error_func)
     # Load the file from the outPath
       tryCatch(
     taxonomy <- base::readRDS(normalizePath(paste0(tempdir(), "/beesTaxonomy.Rda"))),
     error = error_funcFile, warning = error_funcFile)
       }else{
+        
+        # Set destfile if it's not provided by user
+        if(is.null(destfile)){
+          destfile <- paste0(tempdir(), "/beesTaxonomy.Rda")}
         # Download the file to the outPath 
-        tryCatch(utils::download.file(URL, destfile = paste0(tempdir(), "/beesTaxonomy.Rda")),
+        tryCatch(utils::download.file(URL, destfile = destfile,
+                                      method = method,
+                                      ...),
                  error = error_func, warning = error_func)
         # Load the file from the outPath
         tryCatch(
