@@ -28,14 +28,14 @@ testOut <- BeeBDC::dupePlotR(
 
 
 # Test classes
-    #   testthat::test_that("dupePlotR expected class", {
-    #     testthat::expect_type(testOut, "object")
-    #   })
+   testthat::test_that("dupePlotR expected class", {
+     testthat::expect_type(testOut, "object")
+   })
 
-    #   #  # Check directory that the plot was saved
-    #   testthat::test_that("dupePlotR plot saved?", {
-    #     testthat::expect_true(inherits(testOut, c("ggplot", "ggplot2::ggplot")))
-    #   })
+   #  # Check directory that the plot was saved
+   testthat::test_that("dupePlotR plot saved?", {
+     testthat::expect_true(inherits(testOut, c("ggplot", "ggplot2::ggplot")))
+   })
 
 # Check directory that the plot was saved
 testthat::test_that("dupePlotR plot saved?", {
